import { Link, useNavigate } from 'react-router-dom';
import { useState, useEffect } from 'react';
import axios from 'axios'
import { User, Users } from '../types';

import TopBar from '../components/TopBar';

export default function Admin () {
    const navigate = useNavigate();
    const [user, setUser] = useState<User>();
    const [users, setUsers] = useState<Users>([]);

    useEffect(() => {
        const token = localStorage.getItem('token');
        if (!token) {
            navigate('/login');
        } else {
            axios
                .post('/api/@me', {
                    token: token
                })
                .then((response) => {
                    setUser(response.data);
                })
                .catch(() => {
                    navigate('/login');
                });

            axios
                .post('/api/users', {
                    token: token
                })
                .then((response) => {
                    setUsers(response.data);
                })
                .catch((error) => {
                    console.error('Error fetching users:', error.response.data);
                });
        }
    }, []);

    if (!user) {
        return (
            <div className='bank-page'>
                <TopBar user={user} />
                <div className='bank-section'>
                    <h1>Loading...</h1>
                </div>
            </div>
        );
    }

    return (
        <div className='bank-page'>
            <TopBar user={user} />
            <div className='bank-section'>
                <h2>Admin Panel</h2>
                <p>Manage users, accounts, and cards.</p>
            </div>
            <div className='bank-section'>
                <h2>Users</h2>
                {users.length > 0 ? (
                    users.map((user) => (
                        <div key={user.id}>
                            <p>
                                <strong>{user.name}</strong> - {user.lastname}
                            </p>
                            <Link to={`/admin/user/${user.id}`}>View Details</Link>
                        </div>
                    ))
                ) : (
                    <p>No users found.</p>
                )}
            </div>
        </div>
    );
}